@@ -16,7 +16,7 @@ seconds_in_hour = 3600
 seconds_in_half_hour = 1800
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.6.3'
+jaws_version = '0.6.4'
 
 ###############################################################################
 
@@ -136,10 +136,10 @@ def load_dataset_attributes(name, ds, args, **kwargs):
     if not args.no_drv_tm:
         no_drv_tm_vars = ['hour', 'month', 'day', 'day_of_year']
 
-    if args.rigb:
-        rigb_vars = ['tilt_direction', 'tilt_angle', 'fsds_adjusted', 'cloud_fraction']
-    else:
-        rigb_vars=[]
+    rigb_vars = []
+
+    if name in ['imau/ant', 'imau/grl', 'gcnet', 'promice']:
+        rigb_vars = kwargs.pop('rigb_vars')
 
     for key, value in attr_dict.items():
         for key1, value1 in value.items():
