@@ -1,4 +1,3 @@
-from datetime import datetime
 import os
 
 import numpy as np
@@ -42,79 +41,34 @@ def get_station(args, input_file, stations):
     return lat, lon, new_name
 
 
-def get_time_and_sza(args, dataframe, longitude, latitude):
-    # Divided by 4 because each hour value is a multiple of 4
-    # and then multiplied by 100 to convert decimal to integer
-    hour_conversion = 100 / 4
-    last_hour = 23
-    seconds_in_hour = common.seconds_in_hour
+def get_time_and_sza(args, dataframe, longitude, latitude, sub_type):
+    seconds_in_30min = 30*60
+    seconds_in_15min = 15*60
+    dtime_1970, tz = common.time_common(args.tz)
     num_rows = dataframe['year'].size
 
     month, day, minutes, time, time_bounds, sza, az = ([0] * num_rows for _ in range(7))
 
-    hour = dataframe['day_of_year']
-    hour = [round(i - int(i), 3) * hour_conversion for i in hour]
-    hour = [int(h) if int(h) <= last_hour else 0 for h in hour]
-
-    dtime_1970, tz = common.time_common(args.tz)
-
-    for idx in range(num_rows):
-        time_year = dataframe['year'][idx]
-        time_j = int(dataframe['day_of_year'][idx])
-        time_hour = hour[idx]
-
-        if time_j <= 366:
-            temp_dtime = '{} {} {}'.format(time_year, time_j, time_hour)
-            temp_dtime = datetime.strptime(temp_dtime, "%Y %j %H")
-            temp_dtime = tz.localize(temp_dtime.replace(tzinfo=None))
-
-            time[idx] = (temp_dtime - dtime_1970).total_seconds()
-        else:
-            # Assign time of previous row, if day_of_year > 366
-            time[idx] = time[idx - 1]
-
-        time_bounds[idx] = (time[idx] - seconds_in_hour, time[idx])
-
-        time[idx] = time[idx] - common.seconds_in_half_hour
-        temp_dtime = datetime.utcfromtimestamp(time[idx])
-
-        solar_angles = sunposition.sunpos(temp_dtime, latitude, longitude, 0)
-        az[idx] = solar_angles[0]
-        sza[idx] = solar_angles[1]
-
-    return month, day, hour, minutes, time, time_bounds, sza, az
-
-
-def derive_times(dataframe, month, day):
-    num_rows = dataframe['year'].size
-    for idx in range(num_rows):
-        month[idx], day[idx] = common.get_month_day(
-            int(dataframe['year'][idx]),
-            int(dataframe['day_of_year'][idx]),
-            True)
-
-
-def grl_time(args, dataframe, longitude, latitude):
-    seconds_in_15min = 15*60
-    # dtime_1970, tz = common.time_common(args.tz)
-    num_rows = dataframe['year'].size
-
-    month, day, time, time_bounds, sza, az = ([0] * num_rows for _ in range(6))
-
     hour = (dataframe['hour_mult_100']/100).astype(int)
-    minutes = (((dataframe['hour_mult_100']/100) % 1) * 100).astype(int)
     temp_dtime = pd.to_datetime(dataframe['year']*1000 + dataframe['day_of_year'].astype(int), format='%Y%j')
 
     dataframe['hour'] = hour
-    dataframe['minutes'] = minutes
     dataframe['dtime'] = temp_dtime
 
     dataframe['dtime'] = pd.to_datetime(dataframe.dtime)
+    dataframe['dtime'] = [tz.localize(i.replace(tzinfo=None)) for i in dataframe['dtime']]
     dataframe['dtime'] += pd.to_timedelta(dataframe.hour, unit='h')
-    dataframe['dtime'] += pd.to_timedelta(dataframe.minutes, unit='m')
 
-    time = (dataframe['dtime'] - datetime(1970, 1, 1)) / np.timedelta64(1, 's') - seconds_in_15min
-    time_bounds = [(i-seconds_in_15min, i+seconds_in_15min) for i in time]
+    if sub_type == 'imau/ant':
+        time = (dataframe['dtime'] - dtime_1970) / np.timedelta64(1, 's') - seconds_in_30min
+        time_bounds = [(i-seconds_in_30min, i+seconds_in_30min) for i in time]
+    elif sub_type == 'imau/grl':
+        minutes = (((dataframe['hour_mult_100']/100) % 1) * 100).astype(int)
+        dataframe['minutes'] = minutes
+        dataframe['dtime'] += pd.to_timedelta(dataframe.minutes, unit='m')
+
+        time = (dataframe['dtime'] - dtime_1970) / np.timedelta64(1, 's') - seconds_in_15min
+        time_bounds = [(i-seconds_in_15min, i+seconds_in_15min) for i in time]
 
     month = pd.DatetimeIndex(dataframe['dtime']).month.values
     day = pd.DatetimeIndex(dataframe['dtime']).day.values
@@ -148,18 +102,9 @@ def imau2nc(args, input_file, output_file, stations):
     common.log(args, 2, 'Retrieving latitude, longitude and station name')
     latitude, longitude, station_name = get_station(args, input_file, stations)
 
-    if sub_type == 'imau/grl':
-        month, day, hour, minutes, time, time_bounds, sza, az = grl_time(
-            args, df, longitude, latitude)
+    common.log(args, 3, 'Calculating time and sza')
+    month, day, hour, minutes, time, time_bounds, sza, az = get_time_and_sza(args, df, longitude, latitude, sub_type)
 
-    elif sub_type == 'imau/ant':
-        common.log(args, 3, 'Calculating time and sza')
-        month, day, hour, minutes, time, time_bounds, sza, az = get_time_and_sza(
-            args, df, longitude, latitude)
-
-        common.log(args, 5, 'Calculating month and day')
-        derive_times(df, month, day)
-    
     ds['month'] = 'time', month
     ds['day'] = 'time', day
     ds['hour'] = 'time', hour
@@ -172,6 +117,7 @@ def imau2nc(args, input_file, output_file, stations):
     ds['latitude'] = tuple(), latitude
     ds['longitude'] = tuple(), longitude
 
+    rigb_vars = []
     if args.rigb:
         common.log(args, 6, 'Detecting clear days')
         clr_df = clearsky.main(ds, args)
@@ -183,9 +129,11 @@ def imau2nc(args, input_file, output_file, stations):
             common.log(args, 8, 'Calculating corrected_fsds')
             ds = fsds_adjust.main(ds, args)
 
+            rigb_vars = ['tilt_direction', 'tilt_angle', 'fsds_adjusted', 'cloud_fraction']
+
     comp_level = args.dfl_lvl
 
-    common.load_dataset_attributes(sub_type, ds, args)
+    common.load_dataset_attributes(sub_type, ds, args, rigb_vars=rigb_vars)
     encoding = common.get_encoding(sub_type, common.get_fillvalue(args), comp_level, args)
 
     common.write_data(args, ds, output_file, encoding)
